@@ -1,26 +1,38 @@
-#**********************************************************************************************************************************
-#**********************************************************************************************************************************
-#
-#  ParaMonte: plain powerful parallel Monte Carlo library.
-#
-#  Copyright (C) 2012-present, The Computational Data Science Lab
-#
-#  This file is part of ParaMonte library.
-#
-#  ParaMonte is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation, version 3 of the License.
-#
-#  ParaMonte is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU Lesser General Public License for more details.
-#
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with ParaMonte.  If not, see <https://www.gnu.org/licenses/>.
-#
-#**********************************************************************************************************************************
-#**********************************************************************************************************************************
+####################################################################################################################################
+####################################################################################################################################
+####
+####   ParaMonte: plain powerful parallel Monte Carlo library.
+####
+####   Copyright (C) 2012-present, The Computational Data Science Lab
+####
+####   This file is part of the ParaMonte library.
+####
+####   ParaMonte is free software: you can redistribute it and/or modify it
+####   under the terms of the GNU Lesser General Public License as published
+####   by the Free Software Foundation, version 3 of the License.
+####
+####   ParaMonte is distributed in the hope that it will be useful,
+####   but WITHOUT ANY WARRANTY; without even the implied warranty of
+####   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+####   GNU Lesser General Public License for more details.
+####
+####   You should have received a copy of the GNU Lesser General Public License
+####   along with the ParaMonte library. If not, see,
+####
+####       https://github.com/cdslaborg/paramonte/blob/master/LICENSE
+####
+####   ACKNOWLEDGMENT
+####
+####   As per the ParaMonte library license agreement terms,
+####   if you use any parts of this library for any purposes,
+####   we ask you to acknowledge the use of the ParaMonte library
+####   in your work (education/research/industry/development/...)
+####   by citing the ParaMonte library as described on this page:
+####
+####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
+####
+####################################################################################################################################
+####################################################################################################################################
 
 import numpy as _np
 import typing as _tp
@@ -34,8 +46,7 @@ import _pmutils as pmutils
 #from _LinePlot import LinePlot
 #from _ScatterPlot import ScatterPlot
 
-class _struct:
-    pass
+class _Struct: pass
 
 ####################################################################################################################################
 #### AutoCorr class
@@ -43,54 +54,70 @@ class _struct:
 
 class AutoCorr:
     """
-    This is the class for generating object of type CorMat which, 
-    upon construction, will provide methods to compute and plot the 
+
+    .. py:class:: AutoCorr
+
+    This is the base class for generating object of type ``AutoCorr``.  
+    Upon construction, will provide methods to compute and plot the 
     autocorrelations of the selected columns of the input dataFrame.
 
-    Parameters
-    ----------
-        dataFrame
-            a Pandas dataframe based upon the selected comlumns of which 
-            the autocorrelations will be computed.
-        columns
-            optional argument that determines the columns of the input dataFrame to be 
-            used in the computation of the autocorrelations. It can have three forms:
-                1. a list of column indices from the input dataFrame.
-                2. a list of column names from dataFrame.columns.
-                3. a range(start,stop,step), representing the column indices in dataFrame.
-            Examples:
-                1. columns = [0,1,4,3]
-                2. columns = ["SampleLogFunc","SampleVariable1"]
-                3. columns = range(17,7,-2)
-            If not provided, the default behavior includes all columns of the dataFrame.
-        rows
-            optional argument that determines the rows of the input dataFrame to be 
-            used in the computation of the autocorrelations. It can be either:
-                1. a range(start,stop,step), or, 
-                2. a list of row indices from dataFrame.index.
-            Examples:
-                1. rows = range(17,7,-2)
-                2. rows = [i for i in range(7,17)]
-            If not provided, the default behavior includes all rows of the dataFrame.
+        **Parameters**
 
-    Attributes
-    ----------
-        All of the parameters described above, except dataFrame.
-            a reference to the dataFrame will be implicitly stored in the object.
-        df
-            a pandas dataframe containing the computed autocorrelations.
-        plot
-            a structure containing the following plotting tools:
-                heatmap
-                    a callable object of class HeatMap which will enable 
-                    plotting of the correlation matrix.
+            dataFrame
+                a Pandas dataframe based upon the selected comlumns of which 
+                the autocorrelations will be computed.
 
-    Returns
-    -------
-        corMat
-            an object of type class CorMat.
+            columns
+                optional argument that determines the columns of the input dataFrame to be 
+                used in the computation of the autocorrelations. It can have three forms:
 
-    ----------------------------------------------------------------------
+                    1. a list of column indices from the input dataFrame.
+                    2. a list of column names from dataFrame.columns.
+                    3. a ``range(start,stop,step)``, representing the column indices in dataFrame.
+
+                Examples:
+
+                    1. ``columns = [0,1,4,3]``
+                    2. ``columns = ["SampleLogFunc","SampleVariable1"]``
+                    3. ``columns = range(17,7,-2)``
+
+                If not provided, the default behavior includes all columns of the dataFrame.
+
+            rows
+                optional argument that determines the rows of the input dataFrame to be 
+                used in the computation of the autocorrelations. It can be either:
+
+                    1. a ``range(start,stop,step)``, or, 
+                    2. a list of row indices from dataFrame.index.
+
+                Examples:
+
+                    1. ``rows = range(17,7,-2)``
+                    2. ``rows = [i for i in range(7,17)]``
+
+                If not provided, the default behavior includes all rows of the dataFrame.
+
+        **Attributes**
+
+            All of the parameters described above, except dataFrame.
+                a reference to the dataFrame will be implicitly stored in the object.
+
+            df
+                a pandas dataframe containing the computed autocorrelations.
+
+            plot
+                a structure containing the following plotting tools:
+
+                    heatmap
+                        a callable object of class HeatMap which will enable 
+                        plotting of the correlation matrix.
+
+        **Returns**
+
+            self
+                an object of type class CorMat.
+
+    ---------------------------------------------------------------------------
     """
 
     def __init__( self
@@ -111,21 +138,24 @@ class AutoCorr:
                 , **kwargs
                 ):
         """
-        calls the get() method of the current instance of the class.
 
-        Parameters
-        ----------
-            reself
-                logical variable. If True, an instance of the object 
-                will be returned upon exit to the calling routine.
-                The default value is False.
-            also, any attributes of the current instance of the class.
+        .. py:method:: __call__(self, reself = False, **kwargs)
 
-        Returns
-        -------
-            the object self if reself = True otherwise, None.
-            However, this method causes side-effects by manipulating 
-            the existing attributes of the object.
+        Calls the ``get()`` method of the current instance of the class.
+
+            **Parameters**
+
+                reself
+                    logical variable. If True, an instance of the object 
+                    will be returned upon exit to the calling routine.
+                    The default value is False.
+                also, any attributes of the current instance of the class.
+
+            **Returns**
+
+                the object ``self`` if ``reself = True`` otherwise, ``None``.
+                However, this method causes side-effects by manipulating 
+                the existing attributes of the object.
 
         """
 
@@ -146,17 +176,20 @@ class AutoCorr:
 
     def get(self):
         """
-        compute the autocorrelations of the selected columns 
+
+        .. py:method:: get(self)
+
+        Computes the autocorrelations of the selected columns 
         of the input dataframe to the object's constructor.
 
-        Parameters
-        ----------
-            None
+            **Parameters**
 
-        Returns
-        -------
-            None. However, this method causes side-effects by manipulating 
-            the existing attributes of the object.
+                None
+
+            **Returns**
+
+                None. However, this method causes side-effects by manipulating 
+                the existing attributes of the object.
 
         """
 
@@ -233,7 +266,7 @@ class AutoCorr:
         #### add plots
         #####################
 
-        self.plot = _struct()
+        self.plot = _Struct()
 
         # add LinePlot
 
